# SyncSign Python SDK

This client library is designed to support the [SyncSign API](https://dev.sync-sign.com/webapi/) for SyncSign IoT system. You can read more about the API by accessing its official documentation.

## Install

```
python3 -m pip install --upgrade syncsign
```

## Usage

- Modify one of the examples with your own API KEY, e.g. `devices_list.py`
- Run with `python devices_list.py`
